@@ -1,17 +1,16 @@
 #!/usr/bin/env python3
 """
-PCILeech Firmware Generator - Unified Entry Point
+PCILeech Firmware Generator - Unified Entry Point with Requirements Enforcement
 
-This is the single entry point for all PCILeech functionality:
-- CLI mode for scripted builds
-- TUI mode for interactive use
-- VFIO checking and system validation
-- Container and local environment support
+This is the single entry point for all PCILeech functionality with automatic
+dependency checking and installation.
 """
 
 import argparse
+import importlib
 import logging
 import os
+import subprocess
 import sys
 from pathlib import Path
 
@@ -20,15 +19,249 @@ project_root = Path(__file__).parent
 sys.path.insert(0, str(project_root))
 sys.path.insert(0, str(project_root / "src"))
 
-# Import our custom utilities
-from src.log_config import setup_logging, get_logger
-from src.string_utils import (
-    safe_format,
-    log_info_safe,
-    log_error_safe,
-    log_warning_safe,
-)
-from src.error_utils import log_error_with_root_cause, format_concise_error
+
+class RequirementsError(Exception):
+    """Raised when requirements cannot be satisfied."""
+
+    pass
+
+
+def check_and_install_requirements():
+    """Check if all requirements are installed and optionally install them."""
+    requirements_file = project_root / "requirements.txt"
+
+    if not requirements_file.exists():
+        print("⚠️  Warning: requirements.txt not found")
+        return True
+
+    # Parse requirements.txt
+    missing_packages = []
+    with open(requirements_file, "r") as f:
+        for line in f:
+            line = line.strip()
+            if not line or line.startswith("#"):
+                continue
+
+            # Handle different requirement formats
+            package_name = (
+                line.split("==")[0]
+                .split(">=")[0]
+                .split("<=")[0]
+                .split("~=")[0]
+                .split("!=")[0]
+            )
+            package_name = package_name.strip()
+
+            # Skip git+https and other URL-based requirements for now
+            if package_name.startswith(("git+", "http://", "https://", "-e")):
+                continue
+
+            # Check if package is importable
+            if not is_package_available(package_name):
+                missing_packages.append(line.strip())
+
+    if not missing_packages:
+        return True
+
+    print("❌ Missing required packages:")
+    for pkg in missing_packages:
+        print(f"   - {pkg}")
+
+    # Ask user if they want to install
+    if os.getenv("PCILEECH_AUTO_INSTALL") == "1":
+        install = True
+    else:
+        print("\nOptions:")
+        print("1. Auto-install missing packages (requires pip)")
+        print("2. Exit and install manually")
+        print("3. Continue anyway (may cause errors)")
+
+        if not os.isatty(sys.stdin.fileno()):
+            print(
+                "\nError: Non-interactive environment detected. Unable to prompt for input."
+            )
+            print(
+                "Set PCILEECH_AUTO_INSTALL=1 to auto-install or run the script in an interactive terminal."
+            )
+            sys.exit(1)
+
+        choice = input("\nChoice [1/2/3]: ").strip()
+        install = choice == "1"
+
+        if choice == "2":
+            print("\nTo install manually:")
+            print(f"pip install -r {requirements_file}")
+            print("\nOr set PCILEECH_AUTO_INSTALL=1 to auto-install next time")
+            sys.exit(1)
+        elif choice == "3":
+            print("⚠️  Continuing without installing dependencies...")
+            return False
+
+    if install:
+        return install_requirements(requirements_file)
+
+    return False
+
+
+def is_package_available(package_name):
+    """Check if a package is available for import."""
+    # Handle package name mappings (PyPI name vs import name)
+    import_mappings = {
+        "pyyaml": "yaml",
+        "pillow": "PIL",
+        "beautifulsoup4": "bs4",
+        "python-dateutil": "dateutil",
+        "msgpack": "msgpack",
+        "protobuf": "google.protobuf",
+        "pycryptodome": "Crypto",
+        "pyserial": "serial",
+        "python-magic": "magic",
+        "opencv-python": "cv2",
+        "scikit-learn": "sklearn",
+        "matplotlib": "matplotlib.pyplot",
+    }
+
+    import_name = import_mappings.get(package_name.lower(), package_name)
+
+    try:
+        importlib.import_module(import_name)
+        return True
+    except ImportError:
+        # Try alternative import patterns
+        alternatives = [
+            package_name.replace("-", "_"),
+            package_name.replace("_", "-"),
+            package_name.lower(),
+        ]
+
+        for alt_name in alternatives:
+            try:
+                importlib.import_module(alt_name)
+                return True
+            except ImportError:
+                continue
+
+        return False
+
+
+def install_requirements(requirements_file):
+    """Install requirements using pip."""
+    print(f"\n📦 Installing requirements from {requirements_file}...")
+
+    try:
+        # Use current Python interpreter to ensure we install to the right environment
+        cmd = [sys.executable, "-m", "pip", "install", "-r", str(requirements_file)]
+
+        # Check if we're in a virtual environment
+        if hasattr(sys, "real_prefix") or (
+            hasattr(sys, "base_prefix") and sys.base_prefix != sys.prefix
+        ):
+            print("🐍 Detected virtual environment")
+        else:
+            print(
+                "⚠️  Installing to system Python (consider using a virtual environment)"
+            )
+            # Ask for confirmation for system-wide install
+            if os.getenv("PCILEECH_AUTO_INSTALL") != "1":
+                confirm = input("Install to system Python? [y/N]: ").strip().lower()
+                if confirm not in ("y", "yes"):
+                    print(
+                        "Aborted. Please use a virtual environment or install manually."
+                    )
+                    sys.exit(1)
+            cmd.append("--user")  # Install to user directory for safety
+
+        # Run pip install
+        result = subprocess.run(cmd, capture_output=True, text=True, check=False)
+
+        if result.returncode == 0:
+            print("✅ Requirements installed successfully")
+            return True
+        else:
+            print(f"❌ Failed to install requirements:")
+            print(f"   stdout: {result.stdout}")
+            print(f"   stderr: {result.stderr}")
+            print(f"\nTry installing manually:")
+            print(f"   pip install -r {requirements_file}")
+            return False
+
+    except FileNotFoundError:
+        print("❌ pip not found. Please install pip first.")
+        return False
+    except Exception as e:
+        print(f"❌ Error installing requirements: {e}")
+        return False
+
+
+def check_critical_imports():
+    """Check for imports that are absolutely required for basic functionality."""
+    critical_packages = {
+        "textual": "TUI functionality (install with: pip install textual)",
+        "rich": "Rich text display (install with: pip install rich)",
+        "psutil": "System information (install with: pip install psutil)",
+    }
+
+    missing_critical = []
+
+    for package, description in critical_packages.items():
+        if not is_package_available(package):
+            missing_critical.append((package, description))
+
+    return missing_critical
+
+
+def safe_import_with_fallback(module_name, fallback_msg=None):
+    """Safely import a module with a helpful error message."""
+    try:
+        return importlib.import_module(module_name)
+    except ImportError as e:
+        if fallback_msg:
+            print(f"❌ {fallback_msg}")
+        else:
+            print(f"❌ Required module '{module_name}' not available")
+            print(f"   Install with: pip install {module_name}")
+        raise RequirementsError(f"Missing required module: {module_name}") from e
+
+
+# Early requirements check before any other imports
+if __name__ == "__main__":
+    # Check requirements before proceeding
+    try:
+        requirements_ok = check_and_install_requirements()
+
+        # Check critical packages that might not be in requirements.txt
+        missing_critical = check_critical_imports()
+        if missing_critical:
+            print("\n❌ Critical packages missing:")
+            for package, description in missing_critical:
+                print(f"   - {package}: {description}")
+
+            if not requirements_ok:
+                print("\nPlease install missing packages and try again.")
+                sys.exit(1)
+
+    except KeyboardInterrupt:
+        print("\n⚠️  Installation interrupted by user")
+        sys.exit(1)
+    except Exception as e:
+        print(f"❌ Error checking requirements: {e}")
+        sys.exit(1)
+
+
+# Import our custom utilities (after requirements check)
+try:
+    from src.error_utils import format_concise_error, log_error_with_root_cause
+    from src.log_config import get_logger, setup_logging
+    from src.string_utils import (
+        log_error_safe,
+        log_info_safe,
+        log_warning_safe,
+        safe_format,
+    )
+except ImportError as e:
+    print(f"❌ Failed to import PCILeech modules: {e}")
+    print("Make sure you're running from the PCILeech project directory")
+    sys.exit(1)
 
 
 def get_available_boards():
@@ -67,7 +300,7 @@ def check_sudo():
 
 
 def check_vfio_requirements():
-    """Check if VFIO modules are loaded."""
+    """Check if VFIO modules are loaded and rebuild constants."""
     logger = get_logger(__name__)
     try:
         # Check if VFIO modules are loaded
@@ -80,9 +313,55 @@ def check_vfio_requirements():
     except FileNotFoundError:
         # /proc/modules not available, skip check
         pass
+
+    # Always rebuild VFIO constants to ensure they match the current kernel
+    log_info_safe(
+        logger, "Rebuilding VFIO constants for current kernel...", prefix="VFIO"
+    )
+    if not rebuild_vfio_constants():
+        log_warning_safe(
+            logger,
+            "VFIO constants rebuild failed - may cause ioctl errors",
+            prefix="VFIO",
+        )
+
     return True
 
 
+def rebuild_vfio_constants():
+    """Rebuild VFIO constants using the build script."""
+    logger = get_logger(__name__)
+    try:
+        result = subprocess.run(
+            ["./build_vfio_constants.sh"],
+            capture_output=True,
+            text=True,
+            cwd=project_root,
+            timeout=60,
+        )
+
+        if result.returncode == 0:
+            log_info_safe(logger, "VFIO constants rebuilt successfully", prefix="VFIO")
+            return True
+        else:
+            log_warning_safe(
+                logger,
+                "VFIO constants rebuild failed: {error}",
+                prefix="VFIO",
+                error=result.stderr,
+            )
+            return False
+
+    except subprocess.TimeoutExpired:
+        log_warning_safe(logger, "VFIO constants rebuild timed out", prefix="VFIO")
+        return False
+    except Exception as e:
+        log_warning_safe(
+            logger, "VFIO constants rebuild error: {error}", prefix="VFIO", error=str(e)
+        )
+        return False
+
+
 def create_parser():
     """Create the main argument parser with subcommands."""
     parser = argparse.ArgumentParser(
@@ -109,27 +388,30 @@ Examples:
   sudo python3 pcileech.py check --device 0000:03:00.0
 
   # Flash firmware
-  sudo python3 pcileech.py flash output/firmware.bin
+  sudo python3 pcileech.py flash firmware.bin
   
   # Generate donor template
-  sudo python3 pcileech.py donor-template -o my_device.json
-  sudo python3 pcileech.py donor-template --blank -o minimal.json  # Minimal template
-  sudo python3 pcileech.py donor-template --bdf 0000:03:00.0  # Pre-fill with device info
-  
-  # Build with donor template output
-  sudo python3 pcileech.py build --bdf 0000:03:00.0 --board pcileech_35t325_x4 --output-template device_template.json
+  sudo python3 pcileech.py donor-template --save-to my_device.json
+
+Environment Variables:
+  PCILEECH_AUTO_INSTALL=1    Automatically install missing dependencies
         """,
     )
 
     # Add global options
     parser.add_argument(
-        "--version", action="version", version="PCILeech Firmware Generator v2.0"
+        "--version", action="version", version="PCILeech Firmware Generator v0.7.4"
     )
     parser.add_argument(
-        "--verbose", "-v", action="store_true", help="Enable verbose output"
+        "--verbose", "-v", action="store_true", help="Enable verbose logging"
     )
     parser.add_argument(
-        "--quiet", "-q", action="store_true", help="Suppress non-error output"
+        "--quiet", "-q", action="store_true", help="Suppress non-error messages"
+    )
+    parser.add_argument(
+        "--skip-requirements-check",
+        action="store_true",
+        help="Skip automatic requirements checking",
     )
 
     # Create subparsers for different modes
@@ -155,16 +437,22 @@ Examples:
         "--enable-variance", action="store_true", help="Enable manufacturing variance"
     )
     build_parser.add_argument(
-        "--output-dir", default="output", help="Output directory for generated files"
+        "--build-dir", default="build", help="Directory for generated firmware files"
     )
     build_parser.add_argument(
-        "--output-template",
-        help="Output donor info JSON template alongside build artifacts",
+        "--generate-donor-template",
+        help="Generate donor info JSON template alongside build artifacts",
     )
     build_parser.add_argument(
         "--donor-template",
         help="Use donor info JSON template to override discovered values",
     )
+    build_parser.add_argument(
+        "--device-type",
+        choices=["generic", "network", "storage", "audio", "graphics"],
+        default="generic",
+        help="Override device type detection (default: auto-detect from class code)",
+    )
 
     # TUI command
     tui_parser = subparsers.add_parser("tui", help="Launch interactive TUI")
@@ -194,10 +482,9 @@ Examples:
         "donor-template", help="Generate donor info template"
     )
     donor_parser.add_argument(
-        "-o",
-        "--output",
+        "--save-to",
         default="donor_info_template.json",
-        help="Output file path (default: donor_info_template.json)",
+        help="File path to save template (default: donor_info_template.json)",
     )
     donor_parser.add_argument(
         "--compact",
@@ -219,9 +506,17 @@ Examples:
 
 def main():
     """Main entry point."""
+    # Parse args early to check for skip flag
     parser = create_parser()
     args = parser.parse_args()
 
+    # Skip requirements check if requested
+    if not args.skip_requirements_check:
+        try:
+            check_and_install_requirements()
+        except RequirementsError:
+            return 1
+
     # Setup logging with our custom configuration
     if args.verbose:
         setup_logging(level=logging.DEBUG)
@@ -248,22 +543,25 @@ def main():
         )
         return 1
 
-    # Route to appropriate handler
-    if args.command == "build":
-        return handle_build(args)
-    elif args.command == "tui":
-        return handle_tui(args)
-    elif args.command == "flash":
-        return handle_flash(args)
-    elif args.command == "check":
-        return handle_check(args)
-    elif args.command == "version":
-        return handle_version(args)
-    elif args.command == "donor-template":
-        return handle_donor_template(args)
-    else:
-        # No command specified, show help
-        parser.print_help()
+    # Route to appropriate handler with safe imports
+    try:
+        if args.command == "build":
+            return handle_build(args)
+        elif args.command == "tui":
+            return handle_tui(args)
+        elif args.command == "flash":
+            return handle_flash(args)
+        elif args.command == "check":
+            return handle_check(args)
+        elif args.command == "version":
+            return handle_version(args)
+        elif args.command == "donor-template":
+            return handle_donor_template(args)
+        else:
+            # No command specified, show help
+            parser.print_help()
+            return 1
+    except RequirementsError:
         return 1
 
 
@@ -290,16 +588,30 @@ def handle_build(args):
         if args.enable_variance:
             cli_args.append("--enable-variance")
 
-        if args.output_template:
-            cli_args.extend(["--output-template", args.output_template])
+        if args.generate_donor_template:
+            cli_args.extend(["--output-template", args.generate_donor_template])
 
         if args.donor_template:
             cli_args.extend(["--donor-template", args.donor_template])
 
+        # Pass device type if specified and not the default
+        if hasattr(args, "device_type") and args.device_type != "generic":
+            cli_args.extend(["--device-type", args.device_type])
+
         # Run the CLI
         return cli_main(cli_args)
 
+    except ImportError as e:
+        log_error_safe(
+            logger, "Failed to import CLI module: {error}", prefix="BUILD", error=str(e)
+        )
+        log_error_safe(
+            logger, "Make sure all dependencies are installed", prefix="BUILD"
+        )
+        return 1
     except Exception as e:
+        from src.error_utils import log_error_with_root_cause
+
         log_error_with_root_cause(logger, "Build failed", e)
         return 1
 
@@ -308,17 +620,11 @@ def handle_tui(args):
     """Handle TUI mode."""
     logger = get_logger(__name__)
     try:
-        # Check if Textual is available
-        try:
-            import textual  # noqa: F401
-        except ImportError:
-            log_error_safe(logger, "Textual framework not installed.", prefix="TUI")
-            log_error_safe(
-                logger,
-                "Please install with: pip install textual rich psutil",
-                prefix="TUI",
-            )
-            return 1
+        # Check if Textual is available with helpful error
+        textual = safe_import_with_fallback(
+            "textual",
+            "Textual framework not installed. Install with: pip install textual rich psutil",
+        )
 
         # Import and run the TUI application
         from src.tui.main import PCILeechTUI
@@ -328,10 +634,14 @@ def handle_tui(args):
         app.run()
         return 0
 
+    except RequirementsError:
+        return 1
     except KeyboardInterrupt:
         log_info_safe(logger, "TUI application interrupted by user", prefix="TUI")
         return 1
     except Exception as e:
+        from src.error_utils import log_error_with_root_cause
+
         log_error_with_root_cause(logger, "TUI failed", e)
         return 1
 
@@ -362,8 +672,6 @@ def handle_flash(args):
             flash_firmware(firmware_path)
         except ImportError:
             # Fallback to direct usbloader if available
-            import subprocess
-
             result = subprocess.run(
                 ["usbloader", "-f", str(firmware_path)], capture_output=True, text=True
             )
@@ -382,6 +690,8 @@ def handle_flash(args):
         return 0
 
     except Exception as e:
+        from src.error_utils import log_error_with_root_cause
+
         log_error_with_root_cause(logger, "Flash failed", e)
         return 1
 
@@ -391,14 +701,14 @@ def handle_check(args):
     logger = get_logger(__name__)
     try:
         # Import the VFIO diagnostics functionality
+        from pathlib import Path
+
         from src.cli.vfio_diagnostics import (
             Diagnostics,
             Status,
-            render,
             remediation_script,
+            render,
         )
-        import subprocess
-        from pathlib import Path
 
         log_info_safe(
             logger,
@@ -479,6 +789,8 @@ def handle_check(args):
         log_error_safe(logger, "Details: {error}", prefix="CHECK", error=str(e))
         return 1
     except Exception as e:
+        from src.error_utils import log_error_with_root_cause
+
         log_error_with_root_cause(logger, "VFIO check failed", e)
         import traceback
 
@@ -490,7 +802,7 @@ def handle_check(args):
 def handle_version(args):
     """Handle version information."""
     logger = get_logger(__name__)
-    log_info_safe(logger, "PCILeech Firmware Generator v2.0", prefix="VERSION")
+    log_info_safe(logger, "PCILeech Firmware Generator v0.7.4", prefix="VERSION")
     log_info_safe(logger, "Copyright (c) 2024 PCILeech Project", prefix="VERSION")
     log_info_safe(logger, "Licensed under MIT License", prefix="VERSION")
 
@@ -540,6 +852,8 @@ def handle_donor_template(args):
                         )
                     return 1
             except Exception as e:
+                from src.error_utils import log_error_with_root_cause
+
                 log_error_with_root_cause(logger, "Error validating template", e)
                 return 1
 
@@ -576,6 +890,8 @@ def handle_donor_template(args):
                     )
                     return 1
             except Exception as e:
+                from src.error_utils import log_error_with_root_cause
+
                 log_error_with_root_cause(logger, "Could not read device info", e)
                 return 1
         elif args.blank:
@@ -590,13 +906,13 @@ def handle_donor_template(args):
 
         # Save the template
         generator.save_template_dict(
-            template, Path(args.output), pretty=not args.compact
+            template, Path(args.save_to), pretty=not args.compact
         )
         log_info_safe(
             logger,
-            "✓ Donor info template saved to: {output}",
+            "✓ Donor info template saved to: {file}",
             prefix="DONOR",
-            output=args.output,
+            file=args.save_to,
         )
 
         if args.bdf:
@@ -627,6 +943,8 @@ def handle_donor_template(args):
         return 0
 
     except Exception as e:
+        from src.error_utils import log_error_with_root_cause
+
         log_error_with_root_cause(logger, "Failed to generate donor template", e)
         return 1
 
