@@ -31,20 +31,24 @@ except ImportError:
     HAS_VFIO_ASSIST = False
 
 # Import safe logging functions
-from string_utils import (log_debug_safe, log_error_safe, log_info_safe,
-                          log_warning_safe)
+from string_utils import log_debug_safe, log_error_safe, log_info_safe, log_warning_safe
 
 # Import proper VFIO constants with kernel-compatible ioctl generation
 from .vfio_constants import VfioGroupStatus  # legacy alias
 from .vfio_constants import VfioRegionInfo  # legacy alias
-from .vfio_constants import (VFIO_DEVICE_GET_REGION_INFO,
-                             VFIO_GROUP_GET_DEVICE_FD, VFIO_GROUP_GET_STATUS,
-                             VFIO_GROUP_SET_CONTAINER,
-                             VFIO_REGION_INFO_FLAG_MMAP,
-                             VFIO_REGION_INFO_FLAG_READ,
-                             VFIO_REGION_INFO_FLAG_WRITE, VFIO_SET_IOMMU,
-                             VFIO_TYPE1_IOMMU, vfio_group_status,
-                             vfio_region_info)
+from .vfio_constants import (
+    VFIO_DEVICE_GET_REGION_INFO,
+    VFIO_GROUP_GET_DEVICE_FD,
+    VFIO_GROUP_GET_STATUS,
+    VFIO_GROUP_SET_CONTAINER,
+    VFIO_REGION_INFO_FLAG_MMAP,
+    VFIO_REGION_INFO_FLAG_READ,
+    VFIO_REGION_INFO_FLAG_WRITE,
+    VFIO_SET_IOMMU,
+    VFIO_TYPE1_IOMMU,
+    vfio_group_status,
+    vfio_region_info,
+)
 from .vfio_helpers import get_device_fd
 
 # Configure global logger
@@ -672,17 +676,21 @@ class VFIOBinderImpl:
 
         # Optionally attach; generators in guests should do this instead
         if self._attach:
+            fd = None
+            cont_fd = None
             try:
                 fd, cont_fd = self._open_vfio_device_fd()
             finally:
-                try:
-                    os.close(fd)
-                except OSError:
-                    pass  # Already closed
-                try:
-                    os.close(cont_fd)
-                except OSError:
-                    pass  # Already closed
+                if fd is not None:
+                    try:
+                        os.close(fd)
+                    except OSError:
+                        pass  # Already closed
+                if cont_fd is not None:
+                    try:
+                        os.close(cont_fd)
+                    except OSError:
+                        pass  # Already closed
 
         return self._path_manager.get_vfio_group_path(self.group_id)
 
