@@ -7,16 +7,26 @@ import fcntl
 import logging
 import os
 
-from .vfio_constants import (VFIO_CHECK_EXTENSION, VFIO_GET_API_VERSION,
-                             VFIO_GROUP_FLAGS_VIABLE, VFIO_GROUP_GET_DEVICE_FD,
-                             VFIO_GROUP_GET_STATUS, VFIO_GROUP_SET_CONTAINER,
-                             VFIO_SET_IOMMU, VFIO_TYPE1_IOMMU,
-                             vfio_group_status)
+from .vfio_constants import (
+    VFIO_CHECK_EXTENSION,
+    VFIO_GET_API_VERSION,
+    VFIO_GROUP_FLAGS_VIABLE,
+    VFIO_GROUP_GET_DEVICE_FD,
+    VFIO_GROUP_GET_STATUS,
+    VFIO_GROUP_SET_CONTAINER,
+    VFIO_SET_IOMMU,
+    VFIO_TYPE1_IOMMU,
+    vfio_group_status,
+)
 
 # Import safe logging functions
 try:
-    from ..string_utils import (log_debug_safe, log_error_safe, log_info_safe,
-                                log_warning_safe)
+    from ..string_utils import (
+        log_debug_safe,
+        log_error_safe,
+        log_info_safe,
+        log_warning_safe,
+    )
 except ImportError:
     # Fallback implementations
     def log_info_safe(logger, template, **kwargs):
@@ -321,6 +331,17 @@ def get_device_fd(bdf: str) -> tuple[int, int]:
                         "EBUSY: Group is busy - may be in use by another container",
                         prefix="VFIO",
                     )
+                elif e.errno == errno.ENOTTY:
+                    log_error_safe(
+                        logger,
+                        "ENOTTY: Inappropriate ioctl - ioctl constant may be incorrect for this kernel version",
+                        prefix="VFIO",
+                    )
+                    log_error_safe(
+                        logger,
+                        "This usually indicates mismatched VFIO ioctl constants between userspace and kernel",
+                        prefix="VFIO",
+                    )
                 raise OSError(f"Failed to link group {group} to container: {e}")
 
             # Set the IOMMU type for the container
