@@ -16,12 +16,14 @@ from dataclasses import dataclass
 from enum import IntEnum
 from typing import Any, Dict, List, Optional, Set, Tuple
 
-from ..pci_capability.constants import (EXTENDED_CAPABILITY_NAMES,
-                                        PCI_CAPABILITIES_POINTER,
-                                        PCI_DEVICE_ID_OFFSET,
-                                        PCI_STATUS_REGISTER,
-                                        PCI_VENDOR_ID_OFFSET,
-                                        STANDARD_CAPABILITY_NAMES)
+from ..pci_capability.constants import (
+    EXTENDED_CAPABILITY_NAMES,
+    PCI_CAPABILITIES_POINTER,
+    PCI_DEVICE_ID_OFFSET,
+    PCI_STATUS_REGISTER,
+    PCI_VENDOR_ID_OFFSET,
+    STANDARD_CAPABILITY_NAMES,
+)
 
 logger = logging.getLogger(__name__)
 
