@@ -9,16 +9,18 @@ This module contains all templating-related functionality including:
 
 # Import with fallback for missing dependencies
 try:
-    from .template_renderer import (TemplateRenderer, TemplateRenderError,
-                                    render_tcl_template)
+    from .template_renderer import (
+        TemplateRenderer,
+        TemplateRenderError,
+        render_tcl_template,
+    )
 except ImportError:
     TemplateRenderer = None
     TemplateRenderError = None
     render_tcl_template = None
 
 try:
-    from .tcl_builder import (BuildContext, TCLBuilder, TCLScriptBuilder,
-                              TCLScriptType)
+    from .tcl_builder import BuildContext, TCLBuilder, TCLScriptBuilder, TCLScriptType
 except ImportError:
     TCLBuilder = None
     TCLScriptBuilder = None
@@ -26,8 +28,7 @@ except ImportError:
     BuildContext = None
 
 try:
-    from .systemverilog_generator import (AdvancedSVGenerator,
-                                          DeviceSpecificLogic)
+    from .systemverilog_generator import AdvancedSVGenerator, DeviceSpecificLogic
 except ImportError:
     SystemVerilogGenerator = None
     AdvancedSVGenerator = None
