@@ -19,8 +19,13 @@ except ImportError:
 
 
 try:
-    from jinja2 import (Environment, FileSystemLoader, StrictUndefined,
-                        Template, TemplateError)
+    from jinja2 import (
+        Environment,
+        FileSystemLoader,
+        StrictUndefined,
+        Template,
+        TemplateError,
+    )
 except ImportError:
     raise ImportError(
         "Jinja2 is required for template rendering. Install with: pip install jinja2"
@@ -410,7 +415,7 @@ class TemplateRenderer:
 
             # Ensure all required context keys have safe defaults
             safe_defaults = {
-                "build_system_version": "2.0",
+                "build_system_version": "0.7.3",  # Default version for build system
                 "integration_type": "pcileech",
                 "pcileech_modules": [],
             }
