@@ -134,7 +134,18 @@ class BuildOrchestrator:
             return False
         except Exception as e:
             if self._current_progress:
-                self._current_progress.add_error(f"Build failed: {str(e)}")
+                error_str = str(e)
+                # Check if this is a platform compatibility error
+                if (
+                    "requires Linux" in error_str
+                    or "platform incompatibility" in error_str
+                    or "only available on Linux" in error_str
+                ):
+                    self._current_progress.add_warning(
+                        f"Build skipped due to platform compatibility: {error_str}"
+                    )
+                else:
+                    self._current_progress.add_error(f"Build failed: {error_str}")
                 await self._notify_progress()
             logger.exception("Build failed with exception")
             raise
